% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/FKM.R
\name{FKM}
\alias{FKM}
\title{KM for continuous Traits in Familial GWAS Data (calculate p-value)}
\usage{
FKM(obj, genotypes, gid, weights = NULL, acc = 1e-04, append.write = NULL)
}
\arguments{
\item{obj}{results saved from FKM_Null_Model.R.}

\item{genotypes}{1st column: gene name; 2nd column: snp name; 3rd-end columns: A matrix of genotypes for each subject (class: data.frame). The order of 3rd-end columns should match id. Coded as 0, 1, 2 and no missing.
This genotype file can be a big file containing all genes or it can be files containing one single gene.}

\item{gid}{A vector of id mapping to samples in genotype file (class: vector). So the order of samples in gid must be the same as the order in genotypes. Make sure it is not a factor. Although gid doesn't have to be in the same order as id, it is suggested to make them sorted in the same order in order to make all files easily to be tracked. No missing.}

\item{weights}{1st column: gene name; 2nd column: snp name; 3rd column: A vector with the length equal to the number of variants in the test (class: data.frame). Default is Null indicating equal weight for all markers}

\item{acc}{Accuracy of numerical integration used in Davies' method. Default 1e-4.}

\item{append.write}{The name of pvalue output file. Write out p-values in real time. Don't need to wait until all genes are processed to get the final output.}
}
\value{
output: continuous trait family KM (F-KM) p-value
}
\description{
This function (FKM) is used to perform famSKAT analysis (Chen et al., 2013) for continuous traits in familial GWAS data
}
\examples{
#####################################################################
### Examples for Continuous Traits in Familial GWAS Data using KM ###
#####################################################################
### Subject IDs are numeric ###
data("FKM_numID")
obj1 <- FKM_Null_Model(phenotype=fkm_n_y$y, id=fkm_n_y$id, fa=fkm_n_y$fa,
mo=fkm_n_y$mo, covariates=NULL)
pvalue1 <- FKM(obj=obj1, genotypes=fkm_n_gene, gid=fkm_n_geneid$gid, weights=NULL,
append.write="./pvalues.out")
# Read in a list of genes files instead of a big file containing all genes
obj <- FKM_Null_Model(phenotype=fkm_n_y$y, id=fkm_n_y$id, fa=fkm_n_y$fa, mo=fkm_n_y$mo,
covariates=NULL)
gene <- split(fkm_n_gene, fkm_n_gene[,1])
for (k in 1:2) {
  gene[[k]]$gene <- as.character(gene[[k]]$gene)
  pvalue1 <- FKM(obj=obj, genotypes=gene[[k]], gid=fkm_n_geneid$gid, weights=NULL,
  append.write="./pvalues.out")
}
### Subject IDs are character ###
data("FKM_charID")
obj1 <- FKM_Null_Model(phenotype=fkm_c_y$y, id=as.character(fkm_c_y$id),
fa=as.character(fkm_c_y$fa), mo=as.character(fkm_c_y$mo),  covariates=NULL)
pvalue1 <- FKM(obj=obj1, genotypes=fkm_c_gene, gid=as.character(fkm_c_geneid$gid),
weights=NULL)
}

